@@ -23,6 +23,7 @@
 #include "changhong.h"
 #include "protocols/necprotocol.h"
 #include "protocols/protonprotocol.h"
+#include <QComboBox>
 
 ChanghongTV1::ChanghongTV1(
   unsigned int index)
@@ -224,6 +225,16 @@ void ChanghongTV2::populateProtocol(
 }
 
 
+void ChanghongTV2::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("TV / Video", QVariant(Input_Key));
+  cb->addItem("Radio", QVariant(Input_Key));
+}
+
+
 ChanghongTV3::ChanghongTV3(
   unsigned int index)
   : PIRKeysetMetaData(
