@@ -23,6 +23,7 @@
 #include "crown.h"
 #include "protocols/necprotocol.h"
 #include "protocols/rc5protocol.h"
+#include <QComboBox>
 
 CrownTV1::CrownTV1(
   unsigned int index)
@@ -89,6 +90,16 @@ void CrownTV1::populateProtocol(
 }
 
 
+void CrownTV1::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("TV", QVariant(Input_Key));
+  cb->addItem("AV", QVariant(AuxInput_Key));
+}
+
+
 CrownAudio1::CrownAudio1(
   unsigned int index)
   : PIRKeysetMetaData(
