@@ -23,6 +23,7 @@
 #include "dreambox.h"
 #include "protocols/xmpprotocol.h"
 #include "protocols/necprotocol.h"
+#include <QComboBox>
 
 
 DreamboxSat1::DreamboxSat1(
@@ -95,6 +96,16 @@ void DreamboxSat1::populateProtocol(
 }
 
 
+void DreamboxSat1::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("TV (pause/play)", QVariant(Input_Key));
+  cb->addItem("Radio", QVariant(TunerInput_Key));
+}
+
+
 DreamboxSat1a::DreamboxSat1a(
   unsigned int index)
   : DreamboxSat1(index)
@@ -256,6 +267,16 @@ void DreamboxSat2::populateProtocol(
 }
 
 
+void DreamboxSat2::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("TV (play/pause)", QVariant(Input_Key));
+  cb->addItem("Radio", QVariant(TunerInput_Key));
+}
+
+
 DreamboxSat3::DreamboxSat3(
   unsigned int index)
   : PIRKeysetMetaData(
@@ -323,6 +344,17 @@ void DreamboxSat3::populateProtocol(
 }
 
 
+void DreamboxSat3::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("TV", QVariant(Input_Key));
+  cb->addItem("Radio", QVariant(TunerInput_Key));
+  cb->addItem("PVR", QVariant(HDDInput_Key));
+}
+
+
 DreamboxSat4::DreamboxSat4(
   unsigned int index)
   : PIRKeysetMetaData(
