@@ -22,6 +22,7 @@
 
 #include "humax.h"
 #include "protocols/necprotocol.h"
+#include <QComboBox>
 
 
 HumaxReceiver1::HumaxReceiver1(
@@ -94,6 +95,16 @@ void HumaxReceiver1::populateProtocol(
 }
 
 
+void HumaxReceiver1::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("TV-Sat", QVariant(Input_Key));
+  cb->addItem("TV-Radio", QVariant(TunerInput_Key));
+}
+
+
 // Ugly!  Humax has two different keysets using the same device code. :(
 HumaxReceiver2::HumaxReceiver2(
   unsigned int index)
@@ -156,6 +167,16 @@ void HumaxReceiver2::populateProtocol(
 }
 
 
+void HumaxReceiver2::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("TV-Sat", QVariant(Input_Key));
+  cb->addItem("TV-Radio", QVariant(TunerInput_Key));
+}
+
+
 HumaxReceiver3::HumaxReceiver3(
   unsigned int index)
   : PIRKeysetMetaData(
@@ -233,3 +254,14 @@ void HumaxReceiver3::populateProtocol(
   addKey("setbookmark", Unmapped_Key, 0x6A, 8);
   addKey("listbookmarks", Unmapped_Key, 0x6B, 8);
 }
+
+
+void HumaxReceiver3::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("Source", QVariant(Input_Key));
+  cb->addItem("List", QVariant(HDDInput_Key));
+  cb->addItem("TV-Radio", QVariant(TunerInput_Key));
+}
