@@ -25,6 +25,7 @@
 #include "protocols/giprotocol.h"
 #include "protocols/necprotocol.h"
 #include "protocols/canalsatprotocol.h"
+#include <QComboBox>
 
 
 Motorola4DTV::Motorola4DTV(
@@ -90,6 +91,16 @@ void Motorola4DTV::populateProtocol(
 }
 
 
+void Motorola4DTV::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("Source", QVariant(Input_Key));
+  cb->addItem("Satellite", QVariant(SatInput_Key));
+}
+
+
 MotorolaSTB1::MotorolaSTB1(
   unsigned int index)
   : PIRKeysetMetaData(
@@ -184,6 +195,16 @@ void MotorolaSTB1::populateProtocol(
 }
 
 
+void MotorolaSTB1::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("Input Toggle", QVariant(Input_Key));
+  cb->addItem("MyDVR", QVariant(HDDInput_Key));
+}
+
+
 MotorolaSTB1a::MotorolaSTB1a(
   unsigned int index)
   : MotorolaSTB1(index)
