@@ -23,6 +23,8 @@
 #include "multichoice.h"
 #include "protocols/rc5protocol.h"
 #include "protocols/xmpprotocol.h"
+#include <QComboBox>
+
 
 MultichoiceSTB1::MultichoiceSTB1(
   unsigned int index)
@@ -92,6 +94,16 @@ void MultichoiceSTB1::populateProtocol(
 }
 
 
+void MultichoiceSTB1::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("TV", QVariant(Input_Key));
+  cb->addItem("Radio", QVariant(TunerInput_Key));
+}
+
+
 MultichoiceSTB2::MultichoiceSTB2(
   unsigned int index)
   : PIRKeysetMetaData(
