@@ -23,6 +23,7 @@
 #include "technisat.h"
 #include "protocols/paceprotocol.h"
 #include "protocols/rc5protocol.h"
+#include <QComboBox>
 
 
 TechnisatSTB1::TechnisatSTB1(
@@ -92,6 +93,16 @@ void TechnisatSTB1::populateProtocol(
 }
 
 
+void TechnisatSTB1::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("TV / R", QVariant(TunerInput_Key));
+  cb->addItem("SAT", QVariant(SatInput_Key));
+}
+
+
 TechnisatSTB1a::TechnisatSTB1a(
   unsigned int index)
   : TechnisatSTB1(index)
@@ -176,11 +187,21 @@ void TechnisatSTB2::populateProtocol(
   addKey("A/B", Audio_Key, 0x1223, 13);
   addKey("STOP", Unmapped_Key, 0x1229, 13);
   addKey("EPG", Guide_Key, 0x122F, 13); // "SFI"
-  addKey("EXT", Input_Key, 0x1238, 13);
+  addKey("EXT", Input_Key, 0x1238, 13);  // ??
   addKey("VT", Teletext_Key, 0x123C, 13); // "TXT"
 }
 
 
+void TechnisatSTB2::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("TV / SAT", QVariant(SatInput_Key));
+  cb->addItem("TV / Radio", QVariant(TunerInput_Key));
+}
+
+
 TechnisatSTB2a::TechnisatSTB2a(
   unsigned int index)
   : TechnisatSTB2(index)
