@@ -22,6 +22,7 @@
 
 #include "viewsat.h"
 #include "protocols/necprotocol.h"
+#include <QComboBox>
 
 
 ViewsatSat1::ViewsatSat1(
@@ -91,6 +92,17 @@ void ViewsatSat1::populateProtocol(
 }
 
 
+void ViewsatSat1::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("Input", QVariant(Input_Key));
+  cb->addItem("Sat", QVariant(SatInput_Key));
+  cb->addItem("Radio", QVariant(TunerInput_Key));
+}
+
+
 ViewsatSat1a::ViewsatSat1a(
   unsigned int index)
   : ViewsatSat1(index)
