@@ -35,6 +35,7 @@
 #include <QKeyEvent>
 #include <QPushButton>
 #include <QStackedWidget>
+#include <QAbstractKineticScroller>
 
 //#include "pirtabwidget.h"
 
@@ -819,6 +820,13 @@ void MainWindow::setupCustomTabWidget()
     this,
     SLOT(switchToPanel(QListWidgetItem *)),
     Qt::QueuedConnection);
+
+  connect(
+    flickableTabs,
+    SIGNAL(itemSelectionChanged()),
+    this,
+    SLOT(updatePanelIndex()),
+    Qt::QueuedConnection);
 }
 
 void MainWindow::disableUpdates()
@@ -882,6 +890,20 @@ void MainWindow::switchToPanel(
 }
 
 
+void MainWindow::updatePanelIndex()
+{
+  QAbstractKineticScroller *scroller =
+    flickableTabs->property("kineticScroller")
+      .value<QAbstractKineticScroller *>();
+
+  if (!scroller->state())
+  {
+    panelStackWidget->setCurrentIndex(
+      flickableTabs->currentRow());
+  }
+}
+
+
 void MainWindow::setupTabs(
   PIRTabBarName name)
 {
