@@ -28,6 +28,7 @@
 
 #include <QSettings>
 #include <QComboBox>
+#include <QFileDialog>
 
 //#include <iostream>
 
@@ -46,9 +47,6 @@ PIRPreferencesForm::PIRPreferencesForm(
   setAttribute(Qt::WA_Maemo5StackedWindow);
   setWindowFlags(windowFlags() | Qt::Window);
 
-  setupMacroComboBox(ui->macroKbdComboBox);
-  setupMacroComboBox(ui->macroBtnComboBox);
-
   QSettings settings("pietrzak.org", "Pierogi");
 
   settings.beginGroup("Preferences");
@@ -87,36 +85,14 @@ PIRPreferencesForm::PIRPreferencesForm(
     }
   }
 
-  if (settings.contains("macroKbdFocus"))
+  if (settings.contains("macroFileName"))
   {
-/*
-    int index = mainWindow->findMacroPack(
-      settings.value("macroKbdFocus").toString());
-*/
-    int index = settings.value("macroKbdFocus").toInt();
+    QString filename = settings.value("macroFileName").toString();
 
-    ui->macroKbdComboBox->setCurrentIndex(index);
-    mainWindow->setMacroKbdFocus(index);
-  }
-  else
-  {
-    mainWindow->setMacroKbdFocus(0);
-  }
-
-  if (settings.contains("macroBtnFocus"))
-  {
-/*
-    int index = mainWindow->findMacroPack(
-      settings.value("macroBtnFocus").toString());
-*/
-    int index = settings.value("macroBtnFocus").toInt();
-
-    ui->macroBtnComboBox->setCurrentIndex(index);
-    mainWindow->setMacroBtnFocus(index);
-  }
-  else
-  {
-    mainWindow->setMacroBtnFocus(0);
+    if (filename != "No File Selected")
+    {
+      loadMacroFile(filename);
+    }
   }
 
   settings.endGroup();
@@ -212,38 +188,6 @@ void PIRPreferencesForm::on_altMainCheckBox_stateChanged(
 }
 
 
-void PIRPreferencesForm::on_macroKbdComboBox_activated(int index)
-{
-  QSettings settings("pietrzak.org", "Pierogi");
-  settings.beginGroup("Preferences");
-  settings.setValue("macroKbdFocus", index);
-  settings.endGroup();
-
-  mainWindow->setMacroKbdFocus(index);
-}
-
-
-void PIRPreferencesForm::on_macroBtnComboBox_activated(int index)
-{
-  QSettings settings("pietrzak.org", "Pierogi");
-  settings.beginGroup("Preferences");
-  settings.setValue("macroBtnFocus", index);
-  settings.endGroup();
-
-  mainWindow->setMacroBtnFocus(index);
-  mainWindow->updateUserButtons();
-}
-
-
-void PIRPreferencesForm::setupMacroComboBox(
-  QComboBox *cb)
-{
-  // Crappy hardcoded list.  Need to replace this...
-  cb->addItem("Standard Controls");
-  cb->addItem("User Defined Keyboard Macros");
-  cb->addItem("Reverse Multitap Keyboard Macros");
-}
-
 void PIRPreferencesForm::on_carrierFrequencySpinBox_valueChanged(int arg1)
 {
   if (arg1 < 30000) arg1 = 30000;
@@ -251,7 +195,46 @@ void PIRPreferencesForm::on_carrierFrequencySpinBox_valueChanged(int arg1)
   mainWindow->setCarrierFrequency((unsigned int) arg1);
 }
 
+
 void PIRPreferencesForm::on_dutyCycleSpinBox_valueChanged(int arg1)
 {
   mainWindow->setDutyCycle((unsigned int) arg1);
 }
+
+
+void PIRPreferencesForm::on_macroFilenameButton_clicked()
+{
+  QString filename = QFileDialog::getOpenFileName(
+    0,
+    tr("Select Macro XML File"));
+
+  loadMacroFile(filename);
+
+  QSettings settings("pietrzak.org", "Pierogi");
+  settings.beginGroup("Preferences");
+  settings.setValue("macroFileName", ui->macroFilenameButton->text());
+  settings.endGroup();
+}
+
+
+void PIRPreferencesForm::loadMacroFile(
+  QString filename)
+{
+  if (filename.isEmpty())
+  {
+    ui->macroFilenameButton->setText("No File Selected");
+    mainWindow->setupMacroForm();
+    return;
+  }
+
+  if (!mainWindow->loadNewMacros(filename))
+  {
+    ui->macroFilenameButton->setText("No File Selected");
+    mainWindow->setupMacroForm();
+    return;
+  }
+
+  ui->macroFilenameButton->setText(filename);
+
+  mainWindow->setupMacroForm();
+}
